@@ -385,3 +385,20 @@ class X_API:
             data["usernames"] = usernames
         response = self._client.open_api_do("POST", "notice", "", json=data).json()
         return response
+
+    def update_calibset(self,
+                        id: int,
+                        status: Optional[int] = None,
+                        pb_url: Optional[str] = None,
+                        log: Optional[str] = None,
+                        folders: Optional[str] = None,
+                        category:  Optional[str] = "default"
+                        )-> Dict[str, Any]:
+        data = {}
+        data["status"] = status
+        data["pb_url"] = pb_url
+        data["log"] = log
+        data["folders"] = folders
+        api = "model_calib/"+str(id) + "?category=" + category
+        response = self._client.open_api_do("PUT", api , "", json=data).json()
+        return response
\ No newline at end of file
